ident_value

Function ident_value 

pub fn ident_value(ident: &Ident) -> &str
Get the unquoted value from an Ident.

sqlparser’s Ident already stores the unquoted value in .value, so this is just a convenience accessor that mirrors the string-based unquote_identifier function.