LintDocument

Struct LintDocument 

pub struct LintDocument<'a> {
    pub sql: &'a str,
    pub source_sql: Option<&'a str>,
    pub source_statement_ranges: Vec<Option<Range<usize>>>,
    pub dialect: Dialect,
    pub statements: Vec<LintStatement<'a>>,
    pub tokens: Vec<LintToken>,
    pub raw_tokens: Vec<TokenWithSpan>,
    pub noqa: NoqaMap,
    pub parser_fallback_used: bool,
    pub tokenizer_fallback_used: bool,
}
Normalized lint input model for a single SQL source.

Fields

sql: &'a strsource_sql: Option<&'a str>source_statement_ranges: Vec<Option<Range<usize>>>dialect: Dialectstatements: Vec<LintStatement<'a>>tokens: Vec<LintToken>raw_tokens: Vec<TokenWithSpan>noqa: NoqaMapparser_fallback_used: booltokenizer_fallback_used: bool

Implementations

Source

impl<'a> LintDocument<'a>

pub fn new( sql: &'a str, dialect: Dialect, statements: Vec<LintStatement<'a>>, ) -> Self

Build a lint document from source SQL and parsed statements.

pub fn new_with_parser_fallback( sql: &'a str, dialect: Dialect, statements: Vec<LintStatement<'a>>, parser_fallback_used: bool, ) -> Self

Build a lint document with parser fallback provenance metadata.

pub fn new_with_parser_fallback_and_source( sql: &'a str, source_sql: Option<&'a str>, dialect: Dialect, statements: Vec<LintStatement<'a>>, parser_fallback_used: bool, source_statement_ranges: Option<Vec<Option<Range<usize>>>>, ) -> Self

Build a lint document with parser fallback metadata and optional untemplated source mapping.