LINT_AM_007: Ambiguous set-operation columns.
SQLFluff AM07 parity: set-operation branches should resolve to the same number of output columns when wildcard expansion is deterministically known.
LINT_AM_007: Ambiguous set-operation columns.
SQLFluff AM07 parity: set-operation branches should resolve to the same number of output columns when wildcard expansion is deterministically known.