LINT_CV_004: Prefer COUNT(*) over COUNT(1).
COUNT(1) and COUNT(*) are semantically identical in all major databases,
but COUNT(*) is the standard convention and more clearly expresses intent.
LINT_CV_004: Prefer COUNT(*) over COUNT(1).
COUNT(1) and COUNT(*) are semantically identical in all major databases,
but COUNT(*) is the standard convention and more clearly expresses intent.