LINT_CV_007: Statement brackets.
SQLFluff CV07 parity (current scope): avoid wrapping an entire statement in unnecessary outer brackets.
LINT_CV_007: Statement brackets.
SQLFluff CV07 parity (current scope): avoid wrapping an entire statement in unnecessary outer brackets.