Module cv_010

Module cv_010 

LINT_CV_010: Consistent usage of preferred quotes for quoted literals.

SQLFluff CV10 parity: detects inconsistent quoting of string literals in dialects where both single and double quotes denote strings (BigQuery, Databricks/SparkSQL, Hive, MySQL). Applies Black-style quote normalization for autofixes.

Structs

ConventionQuotedLiterals