LINT_CV_011: Casting style.
SQLFluff CV11 parity: detect mixed use of ::, CAST(), and CONVERT()
within the same statement and emit autofix edits to normalise to the
preferred style.
LINT_CV_011: Casting style.
SQLFluff CV11 parity: detect mixed use of ::, CAST(), and CONVERT()
within the same statement and emit autofix edits to normalise to the
preferred style.