Module st_009

Module st_009 

LINT_ST_009: Reversed JOIN condition ordering.

Detect predicates where the newly joined relation appears on the left side and prior relation on the right side (e.g. o.user_id = u.id).

Structs

StructureJoinConditionOrder