pub fn parse_sql_with_dialect_output(
sql: &str,
dialect: Dialect,
) -> Result<ParseSqlOutput, ParseError>Expand description
Parse SQL using the specified dialect and report whether parser fallback was used.
pub fn parse_sql_with_dialect_output(
sql: &str,
dialect: Dialect,
) -> Result<ParseSqlOutput, ParseError>Parse SQL using the specified dialect and report whether parser fallback was used.