pub fn ident_value(ident: &Ident) -> &strExpand description
Get the unquoted value from an Ident.
sqlparser’s Ident already stores the unquoted value in .value,
so this is just a convenience accessor that mirrors the string-based
unquote_identifier function.